![FiQuS logo](https://gitlab.cern.ch/steam/fiqus/-/raw/master/docs/images/FiQuS_name_logo.svg)

# Introduction
Source code for STEAM **FiQuS** (**Fi**nite Element Method **Qu**ench **S**imulation) tool.

# Publications

- A. Vitrano et al, "An Open-Source Finite Element Quench Simulation Tool for Superconducting Magnets," in IEEE Transactions on Applied Superconductivity, vol. 33, no. 5, pp. 1-6, Aug. 2023, Art no. 4702006, doi: [10.1109/TASC.2023.3259332](https://ieeexplore.ieee.org/abstract/document/10077402).

- M. Wozniak et al, "Fast Quench Propagation Conductor for Protecting Canted Cos-Theta Magnets," in IEEE Transactions on Applied Superconductivity, vol. 33, no. 5, pp. 1-5, Aug. 2023, Art no. 4701705, doi: [10.1109/TASC.2023.3247997](https://ieeexplore.ieee.org/document/10050158).

- S. Atalay et al, "An Open-Source 3D FE Quench Simulation Tool for No-Insulation HTS Pancake Coils", in arXiv:2311.09177, doi: [10.48550/arXiv.2311.09177](https://doi.org/10.48550/arXiv.2311.09177)

# Folder Structure
![FiQuS folder structure](https://gitlab.cern.ch/steam/fiqus/-/raw/master/docs/images/FiQuS_folder_structure.svg)

# Installation

## Released version:
```pip install fiqus```

# Links
STEAM website: https://espace.cern.ch/steam/

STEAM-FiQuS website: https://espace.cern.ch/steam/SitePages/FiQuS.aspx

STEAM-FiQuS documentation: https://steam-fiqus.docs.cern.ch/ 

Coverage report: https://steam-fiqus.docs.cern.ch/htmlcov/ 

# Contact
steam-team@cern.ch

# STEAM User Agreement
By using any software of the STEAM framework, users agree with this document:
https://edms.cern.ch/document/2024516

(Copyright © 2022, CERN, Switzerland. All rights reserved.)
